# SPDX-License-Identifier: MIT
"""
mafic.typings
-------------
A collection of Python types for the Lavalink API.
"""

from .common import *
from .http import *
from .incoming import *
from .misc import *
from .outgoing import *
